//[mahjong-utils](../../index.md)/[mahjongutils.hora](index.md)/[throwOnValidationError](throw-on-validation-error.md)

# throwOnValidationError

[common]\
fun [HoraArgs](-hora-args/index.md).[throwOnValidationError](throw-on-validation-error.md)()
